==> spring-boot-3.6.0-source-release.zip: spring-boot-3.6.0/tests/camel-itest-spring-boot/src/test/java/org/apache/camel/itest/springboot/CamelInfinispanTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.itest.springboot;

import org.apache.camel.itest.springboot.util.ArquillianPackager;
import org.jboss.arquillian.container.test.api.Deployment;
import org.jboss.arquillian.junit.Arquillian;
import org.jboss.shrinkwrap.api.Archive;
import org.junit.Test;
import org.junit.Ignore;
import org.junit.runner.RunWith;


@RunWith(Arquillian.class)
@Ignore("Still doesn't work with infinispan 10.x")
public class CamelInfinispanTest extends AbstractSpringBootTestSupport {

    @Deployment
    public static Archive<?> createSpringBootPackage() throws Exception {
        return ArquillianPackager.springBootPackage(createTestConfig());
    }

    public static ITestConfig createTestConfig() {
        return new ITestConfigBuilder()
                .module(inferModuleName(CamelInfinispanTest.class))
                .dependency("org.infinispan:infinispan-client-hotrod:10.1.1.Final")
                .dependency("org.infinispan:infinispan-commons:10.1.1.Final")
                .dependency("org.infinispan:infinispan-component-annotations:10.1.1.Final")
                .dependency("org.infinispan:infinispan-core:10.1.1.Final")
                .dependency("org.infinispan:infinispan-query-dsl:10.1.1.Final")
                .dependency("org.infinispan:infinispan-remote-query-client:10.1.1.Final")
                .disableJmx("org.infinispan:*")
                .build();
    }

    @Test
    public void componentTests() throws Exception {
        this.runComponentTest(config);
        this.runModuleUnitTestsIfEnabled(config);
    }


}

==> spring-boot-3.11.1-source-release.zip: spring-boot-3.11.1/tests/camel-itest-spring-boot/src/test/java/org/apache/camel/itest/springboot/CamelInfinispanTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.itest.springboot;

import org.apache.camel.itest.springboot.util.ArquillianPackager;
import org.jboss.arquillian.container.test.api.Deployment;
import org.jboss.arquillian.junit.Arquillian;
import org.jboss.shrinkwrap.api.Archive;
import org.junit.Test;
import org.junit.Ignore;
import org.junit.runner.RunWith;


@RunWith(Arquillian.class)
public class CamelInfinispanTest extends AbstractSpringBootTestSupport {

    @Deployment
    public static Archive<?> createSpringBootPackage() throws Exception {
        return ArquillianPackager.springBootPackage(createTestConfig());
    }

    public static ITestConfig createTestConfig() {
        return new ITestConfigBuilder()
                .module(inferModuleName(CamelInfinispanTest.class))
                .dependency("org.infinispan:infinispan-client-hotrod:12.1.3.Final")
                .dependency("org.infinispan:infinispan-commons:12.1.3.Final")
                .dependency("org.infinispan:infinispan-component-annotations:12.1.3.Final")
                .dependency("org.infinispan:infinispan-core:12.1.3.Final")
                .dependency("org.infinispan:infinispan-query-dsl:12.1.3.Final")
                .dependency("org.infinispan:infinispan-jboss-marshalling:12.1.3.Final")
                .dependency("org.infinispan:infinispan-marshaller-protostuff:12.1.3.Final")
                .dependency("org.infinispan:infinispan-remote-query-client:12.1.3.Final")
                .dependency("org.infinispan.protostream:protostream-types:4.4.1.Final")
                .dependency("org.infinispan.protostream:protostream:4.4.1.Final")
                .disableJmx("org.infinispan:*")
                .build();
    }

    @Test
    public void componentTests() throws Exception {
        this.runComponentTest(config);
        this.runModuleUnitTestsIfEnabled(config);
    }


}
